@@ -15,7 +15,8 @@ __plugin_meta__ = PluginMetadata(
     name= "奇怪的小功能",
     description= "一些奇奇怪怪的功能和全是BUG的代码",
     type= "application",
-    supported_adapters={"~onebot.v11"}
+    supported_adapters={"~onebot.v11"},
+    usage="在群内发送消息即可"
 )
 
 # 指令集
